///////////////////////////////////////////////////////////////////////////////
//                                                                      
//                        Fulladder Verilog Class Example
//  
///////////////////////////////////////////////////////////////////////////////
//                                                                      
// MODULE:         fulladder
//
// FILENAME:       fulladder.v
// 
// DATE:           30. June 2000
//
// VERSION:        1.0
//
///////////////////////////////////////////////////////////////////////////////
//                                                                      
// DESCRIPTION:    This is the fulladder module of the fulladder design.
//
//
///////////////////////////////////////////////////////////////////////////////
//
// REFERENCES:     (none)
//
///////////////////////////////////////////////////////////////////////////////
//                                                                      
// CHANGES:        Version 2.0 - 30 June 2000
//
///////////////////////////////////////////////////////////////////////////////

  module fulladder (a_i, b_i, cy_i, sum_o, cy_o);
    input    a_i;              // first data bit
    input    b_i;              // second data bit
    input    cy_i;             // carry input
    output   sum_o;            // sum of the data bits
    output   cy_o;             // carry output

    wire     s_sum1;
    wire     s_cy1;
    wire     s_cy2;

    // Instantiate the first halfadder, which is connected to
    // the two data input ports of the fulladder
    halfadder u1 (.a_i(a_i), 
                  .b_i(b_i), 
                  .sum_o(s_sum1), 
                  .cy_o(s_cy1));

    // Instantiate the second halfadder, which is connected to
    // the sum output of i_halfadder1 and to the carry input port.
    halfadder u2 (.a_i(s_sum1), 
                  .b_i(cy_i), 
                  .sum_o(sum_o), 
                  .cy_o(s_cy2));

    // This simple or gate deliveres the final carry flag.
    orgate u3 (.a_i(s_cy1), 
               .b_i(s_cy2), 
               .or_o(cy_o));
    
  endmodule                // fulladder

